# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [5.0.1](https://github.com/conda/rattler/compare/rattler_solve-v5.0.0...rattler_solve-v5.0.1) - 2026-03-18

### Other

- updated the following local packages: rattler_digest, rattler_conda_types

## [5.0.0](https://github.com/conda/rattler/compare/rattler_solve-v4.2.6...rattler_solve-v5.0.0) - 2026-03-16

### Added

- [**breaking**] Make name in MatchSpec non-optional ([#2132](https://github.com/conda/rattler/pull/2132))
- add dependency override option to solver ([#2090](https://github.com/conda/rattler/pull/2090))

### Fixed

- exclude no-timestamp packages in resolvo min_age dedup ([#2185](https://github.com/conda/rattler/pull/2185))
- merge issues on main ([#2156](https://github.com/conda/rattler/pull/2156))

## [4.2.6](https://github.com/conda/rattler/compare/rattler_solve-v4.2.5...rattler_solve-v4.2.6) - 2026-02-25

### Other

- updated the following local packages: rattler_conda_types

## [4.2.5](https://github.com/conda/rattler/compare/rattler_solve-v4.2.4...rattler_solve-v4.2.5) - 2026-02-20

### Other

- updated the following local packages: rattler_conda_types

## [4.2.4](https://github.com/conda/rattler/compare/rattler_solve-v4.2.3...rattler_solve-v4.2.4) - 2026-02-19

### Other

- use `when` syntax instead of `; if` ([#2007](https://github.com/conda/rattler/pull/2007))
- Typo and clippy fixes ([#2047](https://github.com/conda/rattler/pull/2047))

## [4.2.3](https://github.com/conda/rattler/compare/rattler_solve-v4.2.2...rattler_solve-v4.2.3) - 2026-02-04

### Other

- updated the following local packages: rattler_conda_types

## [4.2.2](https://github.com/conda/rattler/compare/rattler_solve-v4.2.1...rattler_solve-v4.2.2) - 2026-01-22

### Other

- updated the following local packages: rattler_conda_types

## [4.2.1](https://github.com/baszalmstra/rattler/compare/rattler_solve-v4.2.0...rattler_solve-v4.2.1) - 2026-01-22

### Fixed

- changelog

## [4.2.0](https://github.com/conda/rattler/compare/rattler_solve-v4.1.2...rattler_solve-v4.2.0) - 2026-01-22

### Added

- add support for `packages.whl` and wheel archives types ([#1988](https://github.com/conda/rattler/pull/1988))

### Other

- add type for archive file name ([#1999](https://github.com/conda/rattler/pull/1999))
- Run `cargo clippy --fix` (from nightly) ([#1992](https://github.com/conda/rattler/pull/1992))

## [4.1.2](https://github.com/conda/rattler/compare/rattler_solve-v4.1.1...rattler_solve-v4.1.2) - 2025-12-18

### Fixed

- split on ';' when fetching dependencies in repodata ([#1919](https://github.com/conda/rattler/pull/1919))

### Other

- update README.md with new banner image ([#1926](https://github.com/conda/rattler/pull/1926))

## [4.1.1](https://github.com/conda/rattler/compare/rattler_solve-v4.1.0...rattler_solve-v4.1.1) - 2025-12-08

### Other

- added resolvo #188 reproducer ([#1898](https://github.com/conda/rattler/pull/1898))

## [4.1.0](https://github.com/conda/rattler/compare/rattler_solve-v4.0.1...rattler_solve-v4.1.0) - 2025-11-27

### Added

- *(solver)* add minimum package age filter for security ([#1890](https://github.com/conda/rattler/pull/1890))
- add condition dependency and `extras` support for libsolv ([#1836](https://github.com/conda/rattler/pull/1836))

## [4.0.1](https://github.com/conda/rattler/compare/rattler_solve-v4.0.0...rattler_solve-v4.0.1) - 2025-11-25

### Fixed

- *(rattler_solve)* handle unparsable dependencies gracefully in sorting ([#1884](https://github.com/conda/rattler/pull/1884))
- *(solver)* conditionals on root requirements ([#1880](https://github.com/conda/rattler/pull/1880))

## [4.0.0](https://github.com/conda/rattler/compare/rattler_solve-v3.1.2...rattler_solve-v4.0.0) - 2025-11-22

### Other

- make `extras` and `conditionals` runtime-configurable ([#1816](https://github.com/conda/rattler/pull/1816))

## [3.1.2](https://github.com/conda/rattler/compare/rattler_solve-v3.1.1...rattler_solve-v3.1.2) - 2025-11-20

### Other

- updated the following local packages: rattler_conda_types

## [3.1.1](https://github.com/conda/rattler/compare/rattler_solve-v3.1.0...rattler_solve-v3.1.1) - 2025-11-19

### Other

- updated the following local packages: rattler_conda_types

## [3.1.0](https://github.com/conda/rattler/compare/rattler_solve-v3.0.9...rattler_solve-v3.1.0) - 2025-11-13

### Added

- Add glob support for package name in matchspec ([#1480](https://github.com/conda/rattler/pull/1480))
- move repodata fetch logic to tools crate ([#1820](https://github.com/conda/rattler/pull/1820))
- parse matchspec conditions and translate to resolvo ([#1545](https://github.com/conda/rattler/pull/1545))

## [3.0.9](https://github.com/conda/rattler/compare/rattler_solve-v3.0.8...rattler_solve-v3.0.9) - 2025-10-28

### Fixed

- timestamp serialization as milliseconds ([#1776](https://github.com/conda/rattler/pull/1776))

## [3.0.8](https://github.com/conda/rattler/compare/rattler_solve-v3.0.7...rattler_solve-v3.0.8) - 2025-10-18

### Other

- updated the following local packages: rattler_conda_types

## [3.0.7](https://github.com/conda/rattler/compare/rattler_solve-v3.0.6...rattler_solve-v3.0.7) - 2025-10-17

### Other

- updated the following local packages: rattler_digest, rattler_conda_types

## [3.0.6](https://github.com/conda/rattler/compare/rattler_solve-v3.0.5...rattler_solve-v3.0.6) - 2025-10-14

### Other

- updated the following local packages: rattler_digest, rattler_conda_types

## [3.0.5](https://github.com/conda/rattler/compare/rattler_solve-v3.0.4...rattler_solve-v3.0.5) - 2025-10-03

### Other

- updated the following local packages: rattler_conda_types

## [3.0.4](https://github.com/conda/rattler/compare/rattler_solve-v3.0.3...rattler_solve-v3.0.4) - 2025-09-30

### Other

- updated the following local packages: rattler_conda_types

## [3.0.3](https://github.com/conda/rattler/compare/rattler_solve-v3.0.2...rattler_solve-v3.0.3) - 2025-09-05

### Other

- updated the following local packages: rattler_conda_types

## [3.0.2](https://github.com/conda/rattler/compare/rattler_solve-v3.0.1...rattler_solve-v3.0.2) - 2025-09-02

### Other

- updated the following local packages: rattler_conda_types

## [3.0.1](https://github.com/conda/rattler/compare/rattler_solve-v3.0.0...rattler_solve-v3.0.1) - 2025-08-15

### Other

- updated the following local packages: rattler_conda_types

## [3.0.0](https://github.com/conda/rattler/compare/rattler_solve-v2.1.8...rattler_solve-v3.0.0) - 2025-08-12

### Added

- implement extras with conditional dependencies ([#1542](https://github.com/conda/rattler/pull/1542))

### Other

- `resolvo` bump ([#1576](https://github.com/conda/rattler/pull/1576))

## [2.1.8](https://github.com/conda/rattler/compare/rattler_solve-v2.1.7...rattler_solve-v2.1.8) - 2025-07-23

### Fixed

- indexing `extra-depends` ([#1546](https://github.com/conda/rattler/pull/1546))

## [2.1.7](https://github.com/conda/rattler/compare/rattler_solve-v2.1.6...rattler_solve-v2.1.7) - 2025-07-21

### Other

- bump rust 1.88.0 ([#1536](https://github.com/conda/rattler/pull/1536))

## [2.1.6](https://github.com/conda/rattler/compare/rattler_solve-v2.1.5...rattler_solve-v2.1.6) - 2025-07-14

### Other

- updated the following local packages: rattler_conda_types

## [2.1.5](https://github.com/conda/rattler/compare/rattler_solve-v2.1.4...rattler_solve-v2.1.5) - 2025-07-09

### Other

- updated the following local packages: rattler_conda_types

## [2.1.4](https://github.com/conda/rattler/compare/rattler_solve-v2.1.3...rattler_solve-v2.1.4) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [2.1.3](https://github.com/conda/rattler/compare/rattler_solve-v2.1.2...rattler_solve-v2.1.3) - 2025-06-26

### Other

- updated the following local packages: rattler_conda_types

## [2.1.2](https://github.com/conda/rattler/compare/rattler_solve-v2.1.1...rattler_solve-v2.1.2) - 2025-06-25

### Other

- *(ci)* Update Rust crate criterion to 0.6 ([#1438](https://github.com/conda/rattler/pull/1438))

## [2.1.1](https://github.com/conda/rattler/compare/rattler_solve-v2.1.0...rattler_solve-v2.1.1) - 2025-06-23

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [2.1.0](https://github.com/conda/rattler/compare/rattler_solve-v2.0.0...rattler_solve-v2.1.0) - 2025-05-23

### Added

- control over selection of .conda and .tar.bz2 ([#1344](https://github.com/conda/rattler/pull/1344))

## [2.0.0](https://github.com/conda/rattler/compare/rattler_solve-v1.4.6...rattler_solve-v2.0.0) - 2025-05-16

### Added

- allows enabling of resolvo diagnostics ([#1296](https://github.com/conda/rattler/pull/1296))

## [1.4.6](https://github.com/conda/rattler/compare/rattler_solve-v1.4.5...rattler_solve-v1.4.6) - 2025-05-03

### Other

- lock workspace member dependencies ([#1279](https://github.com/conda/rattler/pull/1279))

## [1.4.5](https://github.com/conda/rattler/compare/rattler_solve-v1.4.4...rattler_solve-v1.4.5) - 2025-04-17

### Other

- bump resolvo 0.9.0 ([#1259](https://github.com/conda/rattler/pull/1259))

## [1.4.4](https://github.com/conda/rattler/compare/rattler_solve-v1.4.3...rattler_solve-v1.4.4) - 2025-04-10

### Other

- update Cargo.toml dependencies

## [1.4.3](https://github.com/conda/rattler/compare/rattler_solve-v1.4.2...rattler_solve-v1.4.3) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [1.4.2](https://github.com/conda/rattler/compare/rattler_solve-v1.4.1...rattler_solve-v1.4.2) - 2025-03-14

### Other

- updated the following local packages: rattler_conda_types

## [1.4.1](https://github.com/conda/rattler/compare/rattler_solve-v1.4.0...rattler_solve-v1.4.1) - 2025-03-10

### Other

- update Cargo.toml dependencies

## [1.4.0](https://github.com/conda/rattler/compare/rattler_solve-v1.3.11...rattler_solve-v1.4.0) - 2025-03-04

### Added

- *(js)* compile `rattler_solve` and `rattler_repodata_gateway` ([#1108](https://github.com/conda/rattler/pull/1108))

## [1.3.11](https://github.com/conda/rattler/compare/rattler_solve-v1.3.10...rattler_solve-v1.3.11) - 2025-02-28

### Other

- update Cargo.toml dependencies

## [1.3.10](https://github.com/conda/rattler/compare/rattler_solve-v1.3.9...rattler_solve-v1.3.10) - 2025-02-27

### Other

- updated the following local packages: rattler_conda_types

## [1.3.9](https://github.com/conda/rattler/compare/rattler_solve-v1.3.8...rattler_solve-v1.3.9) - 2025-02-25

### Other

- updated the following local packages: rattler_conda_types

## [1.3.8](https://github.com/conda/rattler/compare/rattler_solve-v1.3.7...rattler_solve-v1.3.8) - 2025-02-18

### Other

- update Cargo.toml dependencies

## [1.3.7](https://github.com/conda/rattler/compare/rattler_solve-v1.3.6...rattler_solve-v1.3.7) - 2025-02-06

### Other

- bump rust 1.84.1 (#1053)

## [1.3.6](https://github.com/conda/rattler/compare/rattler_solve-v1.3.5...rattler_solve-v1.3.6) - 2025-02-03

### Other

- updated the following local packages: rattler_conda_types

## [1.3.5](https://github.com/conda/rattler/compare/rattler_solve-v1.3.4...rattler_solve-v1.3.5) - 2025-01-23

### Other

- updated the following local packages: rattler_conda_types

## [1.3.4](https://github.com/conda/rattler/compare/rattler_solve-v1.3.3...rattler_solve-v1.3.4) - 2025-01-09

### Other

- updated the following local packages: rattler_conda_types

## [1.3.3](https://github.com/conda/rattler/compare/rattler_solve-v1.3.2...rattler_solve-v1.3.3) - 2025-01-09

### Other

- updated the following local packages: rattler_conda_types, rattler_libsolv_c

## [1.3.2](https://github.com/conda/rattler/compare/rattler_solve-v1.3.1...rattler_solve-v1.3.2) - 2025-01-08

### Other

- updated the following local packages: rattler_conda_types, rattler_digest

## [1.3.1](https://github.com/conda/rattler/compare/rattler_solve-v1.3.0...rattler_solve-v1.3.1) - 2024-12-20

### Other

- updated the following local packages: rattler_conda_types

## [1.3.0](https://github.com/conda/rattler/compare/rattler_solve-v1.2.6...rattler_solve-v1.3.0) - 2024-12-17

### Added

- speed up `PrefixRecord` loading (#984)

### Other

- update everything (#987)

## [1.2.6](https://github.com/conda/rattler/compare/rattler_solve-v1.2.5...rattler_solve-v1.2.6) - 2024-12-13

### Other

- updated the following local packages: rattler_conda_types

## [1.2.5](https://github.com/conda/rattler/compare/rattler_solve-v1.2.4...rattler_solve-v1.2.5) - 2024-12-12

### Other
- updated the following local packages: rattler_conda_types

## [1.2.4](https://github.com/conda/rattler/compare/rattler_solve-v1.2.3...rattler_solve-v1.2.4) - 2024-11-30

### Other

- updated the following local packages: rattler_conda_types

## [1.2.3](https://github.com/conda/rattler/compare/rattler_solve-v1.2.2...rattler_solve-v1.2.3) - 2024-11-18

### Other

- updated the following local packages: rattler_conda_types

## [1.2.2](https://github.com/conda/rattler/compare/rattler_solve-v1.2.1...rattler_solve-v1.2.2) - 2024-11-14

### Other

- updated the following local packages: rattler_conda_types

## [1.2.1](https://github.com/conda/rattler/compare/rattler_solve-v1.2.0...rattler_solve-v1.2.1) - 2024-11-05

### Fixed

- solver crash when using unrelated locked record ([#927](https://github.com/conda/rattler/pull/927))

### Other

- bump py-rattler to 0.8.1 ([#929](https://github.com/conda/rattler/pull/929))

## [1.2.0](https://github.com/conda/rattler/compare/rattler_solve-v1.1.0...rattler_solve-v1.2.0) - 2024-11-04

### Added

- use python_site_packages_path field when available for installing noarch: python packages, CEP-17 ([#909](https://github.com/conda/rattler/pull/909))
- Add `PackageRecord::validate` function ([#911](https://github.com/conda/rattler/pull/911))

### Other

- root constraint shouldnt crash ([#916](https://github.com/conda/rattler/pull/916))
- release ([#903](https://github.com/conda/rattler/pull/903))

## [1.1.0](https://github.com/conda/rattler/compare/rattler_solve-v1.0.10...rattler_solve-v1.1.0) - 2024-10-07

### Added

- add sorting bench and makes test same as feature test ([#897](https://github.com/conda/rattler/pull/897))

### Fixed

- sorting test should also load dependencies ([#896](https://github.com/conda/rattler/pull/896))

### Other

- add snapshot tests to verify solver sorting order ([#895](https://github.com/conda/rattler/pull/895))

## [1.0.10](https://github.com/conda/rattler/compare/rattler_solve-v1.0.9...rattler_solve-v1.0.10) - 2024-10-03

### Other

- updated the following local packages: rattler_conda_types

## [1.0.9](https://github.com/conda/rattler/compare/rattler_solve-v1.0.8...rattler_solve-v1.0.9) - 2024-10-01

### Other

- update resolvo ([#881](https://github.com/conda/rattler/pull/881))

## [1.0.8](https://github.com/conda/rattler/compare/rattler_solve-v1.0.7...rattler_solve-v1.0.8) - 2024-09-23

### Other

- updated the following local packages: rattler_conda_types

## [1.0.7](https://github.com/conda/rattler/compare/rattler_solve-v1.0.6...rattler_solve-v1.0.7) - 2024-09-09

### Other

- bump resolvo 0.8.0 ([#857](https://github.com/conda/rattler/pull/857))

## [1.0.6](https://github.com/conda/rattler/compare/rattler_solve-v1.0.5...rattler_solve-v1.0.6) - 2024-09-05

### Fixed
- remaining typos ([#854](https://github.com/conda/rattler/pull/854))
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [1.0.5](https://github.com/conda/rattler/compare/rattler_solve-v1.0.4...rattler_solve-v1.0.5) - 2024-09-03

### Other
- make PackageCache multi-process safe ([#837](https://github.com/conda/rattler/pull/837))

## [1.0.4](https://github.com/conda/rattler/compare/rattler_solve-v1.0.3...rattler_solve-v1.0.4) - 2024-09-02

### Fixed
- Redact spec channel before comparing it with repodata channel  ([#831](https://github.com/conda/rattler/pull/831))

### Other
- Remove note that only libsolv is supported ([#832](https://github.com/conda/rattler/pull/832))

## [1.0.3](https://github.com/conda/rattler/compare/rattler_solve-v1.0.2...rattler_solve-v1.0.3) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- bump resolvo to 0.7.0 ([#805](https://github.com/conda/rattler/pull/805))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [1.0.2](https://github.com/baszalmstra/rattler/compare/rattler_solve-v1.0.1...rattler_solve-v1.0.2) - 2024-08-06

### Other
- updated the following local packages: rattler_conda_types

## [1.0.1](https://github.com/baszalmstra/rattler/compare/rattler_solve-v1.0.0...rattler_solve-v1.0.1) - 2024-08-02

### Fixed
- constraints on virtual packages were ignored ([#795](https://github.com/baszalmstra/rattler/pull/795))

## [0.25.3](https://github.com/conda/rattler/compare/rattler_solve-v0.25.2...rattler_solve-v0.25.3) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.25.2](https://github.com/conda/rattler/compare/rattler_solve-v0.25.1...rattler_solve-v0.25.2) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.25.1](https://github.com/conda/rattler/compare/rattler_solve-v0.25.0...rattler_solve-v0.25.1) - 2024-07-15

### Other
- update Cargo.toml dependencies

## [0.25.0](https://github.com/conda/rattler/compare/rattler_solve-v0.24.2...rattler_solve-v0.25.0) - 2024-07-08

### Added
- add direct url repodata building ([#725](https://github.com/conda/rattler/pull/725))
- add tool to generate resolvo snapshots ([#741](https://github.com/conda/rattler/pull/741))

### Fixed
- run clippy on all targets ([#762](https://github.com/conda/rattler/pull/762))
- This fixes parsing of `ray[default,data] >=2.9.0,<3.0.0` ([#732](https://github.com/conda/rattler/pull/732))

### Other
- bump resolvo to 0.6.0 ([#733](https://github.com/conda/rattler/pull/733))
- Document all features on docs.rs ([#734](https://github.com/conda/rattler/pull/734))

## [0.24.2](https://github.com/conda/rattler/compare/rattler_solve-v0.24.1...rattler_solve-v0.24.2) - 2024-06-06

### Added
- serialize packages from lock file individually ([#728](https://github.com/conda/rattler/pull/728))

## [0.24.1](https://github.com/baszalmstra/rattler/compare/rattler_solve-v0.24.0...rattler_solve-v0.24.1) - 2024-06-04

### Other
- updated the following local packages: rattler_conda_types

## [0.24.0](https://github.com/conda/rattler/compare/rattler_solve-v0.23.2...rattler_solve-v0.24.0) - 2024-06-03

### Added
- add constraints to solve ([#713](https://github.com/conda/rattler/pull/713))

## [0.23.2](https://github.com/conda/rattler/compare/rattler_solve-v0.23.1...rattler_solve-v0.23.2) - 2024-05-28

### Fixed
- ChannelPriority implements Debug ([#701](https://github.com/conda/rattler/pull/701))

## [0.23.1](https://github.com/conda/rattler/compare/rattler_solve-v0.23.0...rattler_solve-v0.23.1) - 2024-05-28

### Added
- add run exports to package data ([#671](https://github.com/conda/rattler/pull/671))

### Other
- enable serialization of enums ([#698](https://github.com/conda/rattler/pull/698))

## [0.23.0](https://github.com/conda/rattler/compare/rattler_solve-v0.22.0...rattler_solve-v0.23.0) - 2024-05-27

### Added
- removed Ord and more ([#673](https://github.com/conda/rattler/pull/673))
- always store purls as a key in lock file ([#669](https://github.com/conda/rattler/pull/669))
- add solve strategies ([#660](https://github.com/conda/rattler/pull/660))

### Fixed
- result grouped by subdir instead of channel ([#666](https://github.com/conda/rattler/pull/666))

### Other
- introducing the installer ([#664](https://github.com/conda/rattler/pull/664))

## [0.22.0](https://github.com/conda/rattler/compare/rattler_solve-v0.21.2...rattler_solve-v0.22.0) - 2024-05-14

### Added
- exclude repodata records based on timestamp ([#654](https://github.com/conda/rattler/pull/654))

## [0.21.2](https://github.com/conda/rattler/compare/rattler_solve-v0.21.1...rattler_solve-v0.21.2) - 2024-05-13

### Added
- high level repodata access ([#560](https://github.com/conda/rattler/pull/560))

### Other
- update README.md

## [0.21.1](https://github.com/conda/rattler/compare/rattler_solve-v0.21.0...rattler_solve-v0.21.1) - 2024-05-06

### Other
- updated the following local packages: rattler_conda_types

## [0.21.0](https://github.com/conda/rattler/compare/rattler_solve-v0.20.7...rattler_solve-v0.21.0) - 2024-04-25

### Added
- add channel priority to solve task and expose to python solve ([#598](https://github.com/conda/rattler/pull/598))

## [0.20.7](https://github.com/conda/rattler/compare/rattler_solve-v0.20.6...rattler_solve-v0.20.7) - 2024-04-25

### Other
- updated the following local packages: rattler_conda_types

## [0.20.6](https://github.com/conda/rattler/compare/rattler_solve-v0.20.5...rattler_solve-v0.20.6) - 2024-04-19

### Added
- make root dir configurable in channel config ([#602](https://github.com/conda/rattler/pull/602))

### Other
- update dependencies incl. reqwest ([#606](https://github.com/conda/rattler/pull/606))

## [0.20.5](https://github.com/baszalmstra/rattler/compare/rattler_solve-v0.20.4...rattler_solve-v0.20.5) - 2024-04-05

### Other
- updated the following local packages: rattler_conda_types

## [0.20.4](https://github.com/conda/rattler/compare/rattler_solve-v0.20.3...rattler_solve-v0.20.4) - 2024-03-30

### Other
- updated the following local packages: rattler_conda_types

## [0.20.3](https://github.com/conda/rattler/compare/rattler_solve-v0.20.2...rattler_solve-v0.20.3) - 2024-03-21

### Other
- updated the following local packages: rattler_conda_types

## [0.20.2](https://github.com/conda/rattler/compare/rattler_solve-v0.20.1...rattler_solve-v0.20.2) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.20.1](https://github.com/conda/rattler/compare/rattler_solve-v0.20.0...rattler_solve-v0.20.1) - 2024-03-08

### Other
- update Cargo.toml dependencies

## [0.20.0](https://github.com/conda/rattler/compare/rattler_solve-v0.19.0...rattler_solve-v0.20.0) - 2024-03-06

### Added
- [**breaking**] optional strict parsing of matchspec and versionspec ([#552](https://github.com/conda/rattler/pull/552))

### Fixed
- removal of multiple packages that clobber each other ([#556](https://github.com/conda/rattler/pull/556))
- correct condition to downweigh track-feature packages ([#545](https://github.com/conda/rattler/pull/545))
- dont use workspace dependencies for local crates ([#546](https://github.com/conda/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_solve-v0.18.0...rattler_solve-v0.19.0) - 2024-02-26
